@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11459 2019-04-16 18:20:57Z Lavender $
+# $Id: __init__.py 11551 2019-05-15 12:12:43Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-04-17 02:20:57 +0800 (週三, 17 四月 2019) $
-# $Revision: 11459 $
+# $Date: 2019-05-15 21:12:43 +0900 (週三, 15 五月 2019) $
+# $Revision: 11551 $
 
 import os
 import sys
@@ -24,9 +24,11 @@ import datetime
 import urllib
 import hashlib
 
-
+from decimal import *
 from collections import OrderedDict
 
+import twder
+
 from Iuppiter.Encoding import utf8
 from Iuppiter.DjangoUtil import DJANGO_VERSION
 from Iuno import warnWithout, update, require
@@ -591,6 +593,11 @@ ECPAY_LOGISTIC = 'ecpay_logistic'
 CATHAYBK = 'cathaybk'
 
 class AllPay2(AllPay):
+    def __init__(self, paymentConf, serviceMethod='post'):
+        super(AllPay2, self).__init__(paymentConf, service_method=serviceMethod)
+        if 'Language' in paymentConf:
+            self.url_dict['Language'] = paymentConf['Language']
+
     def gen_check_out_form(self, dict_url, auto_send=True):
         """
         Generate The Form Submission
@@ -656,6 +663,11 @@ def buildAPIForm(submission, request, apiName, extra={}):
     MERCHANT_TRADE_NO_LEN = 20
 
     total = submission['order_total'].excl_tax
+
+    # USD
+    if submission['order_total'].currency == 'USD':
+        total = total * Decimal(twder.now('USD')[2]) # 當前匯率
+
     basket = submission['basket']
     
     # item name
@@ -736,6 +748,9 @@ def buildAPIForm(submission, request, apiName, extra={}):
             'TradeDesc' : settings.OSCAR_SHOP_NAME, 
             'Remark' : settings.OSCAR_SHOP_NAME,
         }
+
+        if apiName == ECPAY and hasattr(settings, 'ECPAY_LANGUAGE'):
+            data['Language'] = settings.ECPAY_LANGUAGE
         
         if six.PY3:
             data['ItemName'] = data['ItemName'].decode("utf-8")
